@@ -25,12 +25,6 @@ class ExternalBackendConf(SharedBackendConfUtils):
     # Getters
     #
 
-    def h2oCluster(self):
-        return self._get_option(self._jconf.h2oCluster())
-
-    def h2oClusterHost(self):
-        return self._get_option(self._jconf.h2oClusterHost())
-
     def h2oClusterPort(self):
         return self._get_option(self._jconf.h2oClusterPort())
 
@@ -43,8 +37,8 @@ class ExternalBackendConf(SharedBackendConfUtils):
     def clusterInfoFile(self):
         return self._get_option(self._jconf.clusterInfoFile())
 
-    def mapperXmx(self):
-        return self._jconf.mapperXmx()
+    def externalMemory(self):
+        return self._jconf.externalMemory()
 
     def HDFSOutputDir(self):
         return self._get_option(self._jconf.HDFSOutputDir())
@@ -100,36 +94,47 @@ class ExternalBackendConf(SharedBackendConfUtils):
     def externalCommunicationCompression(self):
         return self._jconf.externalCommunicationCompression()
 
+    def externalAutoStartBackend(self):
+        return self._jconf.externalAutoStartBackend()
+
+    def externalK8sH2OServiceName(self):
+        return self._jconf.externalK8sH2OServiceName()
+
+    def externalK8sH2OStatefulsetName(self):
+        return self._jconf.externalK8sH2OStatefulsetName()
+
+    def externalK8sH2OLabel(self):
+        return self._jconf.externalK8sH2OLabel()
+
+    def externalK8sH2OApiPort(self):
+        return self._jconf.externalK8sH2OApiPort()
+
+    def externalK8sNamespace(self):
+        return self._jconf.externalK8sNamespace()
+
+    def externalK8sDockerImage(self):
+        return self._jconf.externalK8sDockerImage()
+
+    def externalK8sDomain(self):
+        return self._jconf.externalK8sDomain()
+
+    def externalK8sServiceTimeout(self):
+        return self._jconf.externalK8sServiceTimeout()
+
+    def mapperXmx(self):
+        return self._jconf.mapperXmx()
+
+    def h2oCluster(self):
+        return self._get_option(self._jconf.h2oCluster())
+
+    def h2oClusterHost(self):
+        return self._get_option(self._jconf.h2oClusterHost())
+
+
     #
     # Setters
     #
 
-    def setH2OCluster(self, ip, port):
-        warnings.warn("The method 'setH2OCluster(ip, port)' also sets backend to external. "
-                      "This side effect will be removed in the version in 3.32.")
-        self._jconf.setH2OCluster(ip, port)
-        return self
-
-    def setClusterSize(self, clusterSize):
-        self._jconf.setClusterSize(clusterSize)
-        return self
-
-    def setClusterStartTimeout(self, clusterStartTimeout):
-        self._jconf.setClusterStartTimeout(clusterStartTimeout)
-        return self
-
-    def setClusterInfoFile(self, path):
-        self._jconf.setClusterInfoFile(path)
-        return self
-
-    def setMapperXmx(self, mem):
-        self._jconf.setMapperXmx(mem)
-        return self
-
-    def setHDFSOutputDir(self, dir):
-        self._jconf.setHDFSOutputDir(dir)
-        return self
-
     def useAutoClusterStart(self):
         self._jconf.useAutoClusterStart()
         return self
@@ -138,12 +143,36 @@ class ExternalBackendConf(SharedBackendConfUtils):
         self._jconf.useManualClusterStart()
         return self
 
-    def setH2ODriverPath(self, path):
-        self._jconf.setH2ODriverPath(path)
+    def setH2OCluster(self, value):
+        self._jconf.setH2OCluster(value)
         return self
 
-    def setYARNQueue(self, queueName):
-        self._jconf.setYARNQueue(queueName)
+    def setClusterSize(self, value):
+        self._jconf.setClusterSize(value)
+        return self
+
+    def setClusterStartTimeout(self, value):
+        self._jconf.setClusterStartTimeout(value)
+        return self
+
+    def setClusterInfoFile(self, value):
+        self._jconf.setClusterInfoFile(value)
+        return self
+
+    def setExternalMemory(self, value):
+        self._jconf.setExternalMemory(value)
+        return self
+
+    def setHDFSOutputDir(self, value):
+        self._jconf.setHDFSOutputDir(value)
+        return self
+
+    def setH2ODriverPath(self, value):
+        self._jconf.setH2ODriverPath(value)
+        return self
+
+    def setYARNQueue(self, value):
+        self._jconf.setYARNQueue(value)
         return self
 
     def setKillOnUnhealthyClusterEnabled(self):
@@ -154,46 +183,86 @@ class ExternalBackendConf(SharedBackendConfUtils):
         self._jconf.setKillOnUnhealthyClusterDisabled()
         return self
 
-    def setKerberosPrincipal(self, principal):
-        self._jconf.setKerberosPrincipal(principal)
+    def setKerberosPrincipal(self, value):
+        self._jconf.setKerberosPrincipal(value)
         return self
 
-    def setKerberosKeytab(self, path):
-        self._jconf.setKerberosKeytab(path)
+    def setKerberosKeytab(self, value):
+        self._jconf.setKerberosKeytab(value)
         return self
 
-    def setRunAsUser(self, user):
-        self._jconf.setRunAsUser(user)
+    def setRunAsUser(self, value):
+        self._jconf.setRunAsUser(value)
         return self
 
-    def setExternalH2ODriverIf(self, iface):
-        self._jconf.setExternalH2ODriverIf(iface)
+    def setExternalH2ODriverIf(self, value):
+        self._jconf.setExternalH2ODriverIf(value)
         return self
 
-    def setExternalH2ODriverPort(self, port):
-        self._jconf.setExternalH2ODriverPort(port)
+    def setExternalH2ODriverPort(self, value):
+        self._jconf.setExternalH2ODriverPort(value)
         return self
 
-    def setExternalH2ODriverPortRange(self, portrange):
-        self._jconf.setExternalH2ODriverPortRange(portrange)
+    def setExternalH2ODriverPortRange(self, value):
+        self._jconf.setExternalH2ODriverPortRange(value)
         return self
 
-    def setExternalExtraMemoryPercent(self, memoryPercent):
-        self._jconf.setExternalExtraMemoryPercent(memoryPercent)
+    def setExternalExtraMemoryPercent(self, value):
+        self._jconf.setExternalExtraMemoryPercent(value)
         return self
 
-    def setExternalBackendStopTimeout(self, timeout):
-        self._jconf.setExternalBackendStopTimeout(timeout)
+    def setExternalBackendStopTimeout(self, value):
+        self._jconf.setExternalBackendStopTimeout(value)
         return self
 
-    def setExternalHadoopExecutable(self, executable):
-        self._jconf.setExternalHadoopExecutable(executable)
+    def setExternalHadoopExecutable(self, value):
+        self._jconf.setExternalHadoopExecutable(value)
         return self
 
-    def setExternalExtraJars(self, paths):
-        self._jconf.setExternalExtraJars(paths)
+    def setExternalExtraJars(self, value):
+        self._jconf.setExternalExtraJars(value)
         return self
 
-    def setExternalCommunicationCompression(self, compression):
-        self._jconf.setExternalCommunicationCompression(compression)
+    def setExternalCommunicationCompression(self, value):
+        self._jconf.setExternalCommunicationCompression(value)
+        return self
+
+    def setExternalAutoStartBackend(self, value):
+        self._jconf.setExternalAutoStartBackend(value)
+        return self
+
+    def setExternalK8sH2OServiceName(self, value):
+        self._jconf.setExternalK8sH2OServiceName(value)
+        return self
+
+    def setExternalK8sH2OStatefulsetName(self, value):
+        self._jconf.setExternalK8sH2OStatefulsetName(value)
+        return self
+
+    def setExternalK8sH2OLabel(self, value):
+        self._jconf.setExternalK8sH2OLabel(value)
+        return self
+
+    def setExternalK8sH2OApiPort(self, value):
+        self._jconf.setExternalK8sH2OApiPort(value)
+        return self
+
+    def setExternalK8sNamespace(self, value):
+        self._jconf.setExternalK8sNamespace(value)
+        return self
+
+    def setExternalK8sDockerImage(self, value):
+        self._jconf.setExternalK8sDockerImage(value)
+        return self
+
+    def setExternalK8sDomain(self, value):
+        self._jconf.setExternalK8sDomain(value)
+        return self
+
+    def setExternalK8sServiceTimeout(self, value):
+        self._jconf.setExternalK8sServiceTimeout(value)
+        return self
+
+    def setMapperXmx(self, value):
+        self._jconf.setMapperXmx(value)
         return self
